###################
### Goobler 2022 ##
###################
# Scripts made by Eric #

_HEADER = '\033[95m'
_OKBLUE = '\033[94m'
_OKCYAN = '\033[96m'
_OKGREEN = '\033[92m'
_WARNING = '\033[93m'
_FAIL = '\033[91m'
_ENDC = '\033[0m'
_BOLD = '\033[1m'
_UNDERLINE = '\033[4m'

def HEADER():
    return _HEADER
def OKBLUE():
    return _OKBLUE
def OKCYAN():
    return _OKCYAN
def OKGREEN():
    return _OKGREEN
def WARNING():
    return _WARNING
def FAIL():
    return _FAIL
def ENDC():
    return _ENDC
def BOLD():
    return _BOLD
def UNDERLINE():
    return _UNDERLINE


import requests
#from config import colors

###################
### Goobler 2022 ##
###################
# Scripts made by Eric #


class colors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'


def hostForever(bool=False, tkn=None):
    if tkn != None:
        resp = requests.post('https://goobler.imango.com.au/api/hosts/hostforever', {"auth": tkn})
    else:
        print(colors.WARNING + colors.BOLD + colors.UNDERLINE + "[GooblerAPI] You cannot run hostForever without a token! Remember, the token is the admin password to your application.")

def startHosting(tkn=None):
  if tkn != None:
    resp = requests.post('https://goobler.imango.com.au/api/hosts/start', {"auth": tkn})
  else:
    print(colors.WARNING + colors.BOLD + colors.UNDERLINE + "[GooblerAPI] You cannot run hostForever without a token! Remember, the token is the admin password to your application.")


import os

###################
### Goobler 2022 ##
###################
# Scripts made by Eric #


def RegisterCommands(dir="./GooblerPKG/basic/commands/"):
  try:
    if os.listdir(dir): pass
  except:
    os.mkdir(dir)
    with open(f'{dir}/Information', 'w') as f:
      f.write('For each command you need to add, make a new .py file inside the parent directory.')

  for each in os.listdir(dir):
    if each.endswith('.py'):
      print("\n Registered command "+str(each))


from li import listarray

###################
### Goobler 2022 ##
###################
# Scripts made by Eric #

class ListValueType:
    def __init__(self, value):
        pass
    String = str()
    Integer = int()

def get_list():
    return listarray

class ListValues:
    def change_value(id, value:ListValueType):
        for item in listarray:
            if id == item:
                item[id] = value